@@ -45,7 +45,10 @@ def get_operator(departure):
 
 
 def get_planned_track(departure):
-    return departure['plannedTrack']
+    if get_actual_track(departure) == '':
+        return departure['plannedTrack']
+    else:
+        return get_actual_track(departure)
 
 
 def get_actual_track(departure):
@@ -96,7 +99,6 @@ def get_parsed_departures(response_json, date_format):
         parsed_departure['route_text'] = get_route_text(departure)
         parsed_departure['operator'] = get_operator(departure)
         parsed_departure['planned_track'] = get_planned_track(departure)
-        parsed_departure['actual_track'] = get_actual_track(departure)
         parsed_departure['delay'] = get_delay(departure, date_format)
         parsed_departure['message'] = get_message(departure)
         parsed_departures.append(parsed_departure)
